@@ -22,7 +22,6 @@
 #ifndef __BIN_NODE_H
 #define __BIN_NODE_H
 
-
 // kind of node
 enum Knode { UNDEF, LIST, ATOM, VAR, PRED };
 
@@ -31,6 +30,7 @@ extern Node* FreeListNodes;
 extern Node* FreeAtomNodes;
 extern Node* NewAtom(char const* s);
 extern Node* NewAtom(char* s);
+extern Node* NewAtom(std::string &s);
 extern Node* NewAtom(const char* s);
 extern Node* NewAtom(long long n);
 extern Node* NewAtom(long double n);
@@ -41,9 +41,9 @@ extern Node* GetLeftNode(Node* goals, Node* &goalscdr, int& level);
 extern Node* EraseLevelNode(Node* goals, int level);
 extern Node* Append(Node* nd1, Node* nd2);
 
-
 extern unsigned int PrCount;
 #define	PRCOUNTLIMIT	(PrCount+1000)
+extern int memspeed_diff;
 
 class Node {
 private:
@@ -63,7 +63,8 @@ public:
 	unsigned int   prcount;
 
 	inline Node() { nextnode = AllNodes->nextnode; 
-			AllNodes->nextnode = this; ref = 1; prcount = 0; }
+			AllNodes->nextnode = this; ref = 1; 
+			prcount = 0; memspeed_diff++;}
 	virtual ~Node() {};
 
 	inline Knode	kind() { return k; }
@@ -126,11 +127,14 @@ private:
 	long double	floatvalue;
 	long double	imagevalue;
 	int		floatvalue_flag;
-	
-	
+
 public:
-	Atom(const char* s) {	k = ATOM; str = new std::string(s); floatvalue_flag=0;}
-	Atom(char* s) {	k = ATOM; str = new std::string(s); floatvalue_flag=0;}
+	Atom(const char* s) {k = ATOM; str = new std::string(s);
+				floatvalue_flag=0;}
+	Atom(char* s) {	k = ATOM; str = new std::string(s); 
+				floatvalue_flag=0;}
+	Atom(std::string &s) {k = ATOM; str = new std::string(s);
+				floatvalue_flag=0;}
 	Atom(long long n) 
 		{
 			char* m = (char*)malloc(256);
@@ -285,6 +289,7 @@ public:
 
 	void Set(const char* s) {*str = s; floatvalue_flag=0;}
 	void Set(char* s) {*str = s; floatvalue_flag=0;}
+	void Set(std::string &s) {*str = s; floatvalue_flag=0;}
 	void Set(long long n) 
 		{
 			char* m = (char*)malloc(256);
