@@ -1,5 +1,5 @@
 /*
- * expression program copyright (C) 2009 - 2010 H.Niwa
+ * expression program copyright (C) 2009 - 2011 H.Niwa
  */
 
 /*
@@ -207,7 +207,7 @@ int Exp_Termi(Context* cx, Node* &exp)
 		}
 	} else if (expbr->kind() == PRED) {
 		Node*	 rval;
-		Context* cx2 = new Context(cx->module);
+		Context* cx2 = new Context(cx->module, cx->modulename);
 		cx2->ioin = cx->ioin;
 		cx2->ioout = cx->ioout;
 		cx2->tokenflag = cx->tokenflag;
@@ -397,7 +397,7 @@ int Exp_Termf(Context* cx, Node* &exp)
 		}
 	} else if (expbr->kind() == PRED) {
 		Node*	 rval;
-		Context* cx2 = new Context(cx->module);
+		Context* cx2 = new Context(cx->module, cx->modulename);
 		cx2->ioin = cx->ioin;
 		cx2->ioout = cx->ioout;
 		cx2->tokenflag = cx->tokenflag;
@@ -586,7 +586,7 @@ int Exp_TermC(Context* cx, Node* &exp)
 		}
 	} else if (expbr->kind() == PRED) {
 		Node*	 rval;
-		Context* cx2 = new Context(cx->module);
+		Context* cx2 = new Context(cx->module, cx->modulename);
 		cx2->ioin = cx->ioin;
 		cx2->ioout = cx->ioout;
 		cx2->tokenflag = cx->tokenflag;
