@@ -42,7 +42,6 @@
 #include "func.h"
 #include "let.h"
 
-extern void PushStack(Context* cx, Node* goals, Node* md, Node* env);
 
 int int_let(Context* cx, Node* n, List* module);
 int int_compare(Context* cx, Node* n, List* module);
@@ -186,7 +185,7 @@ int int_compare(Context* cx, Node* goalscar, List* module)
 //printf("comparei a "); n->print(); printf("\n");
 		
 	cxpush(cx, n);
-	if (Comparingi(cx, n) <= 0 ) {
+	if (Comparingi(cx, n) == 0 ) {
 		cxpop(cx);
 		return 0;
 	}
@@ -721,7 +720,7 @@ int float_compare(Context* cx, Node* goalscar, List* module)
 //printf("compare a "); n->print(); //printf("\n");
 		
 	cxpush(cx, n);
-	if (Comparingf(cx, n) <= 0) {
+	if (Comparingf(cx, n) == 0) {
 		cxpop(cx);
 		return 0;
 	}
@@ -1258,7 +1257,7 @@ int complex_compare(Context* cx, Node* goalscar, List* module)
 //printf("compare a "); n->print(); //printf("\n");
 		
 	cxpush(cx, n);
-	if (ComparingC(cx, n) <= 0) {
+	if (ComparingC(cx, n) == 0) {
 		cxpop(cx);
 		return 0;
 	}
