@@ -1,5 +1,5 @@
 /*
- * matrix program copyright (C) 2009 H.Niwa
+ * matrix program copyright (C) 2009 - 2011 H.Niwa
  */
 
 /*
@@ -48,8 +48,6 @@
 #include "func.h"
 #include "matrix.h"
 
-extern void PushStack(Context* cx, Node* goals, Node* md, Node* env);
-extern int PopStack(Context* cx, Node* &goals, Node* &md, Node* &env);
 
 int matrix_zero(Context* cx, Node* goalscar, List* module);
 int matrix_unit(Context* cx, Node* goalscar, List* module);
@@ -99,6 +97,7 @@ int matrix_norm(Context* cx, Node* goalscar, List* module);
 int matrix_cofact(Context* cx, Node* goalscar, List* module);
 int matrix_adj(Context* cx, Node* goalscar, List* module);
 
+int matrix_copy(Context* cx, Node* goalscar, List* module);
 
 #ifdef __CYGWIN__
 long double fabsl(long double x)
@@ -615,6 +614,9 @@ int matrixmodule(Context* cx, Node* goalscar, Node* goalscdr,
 		} else if (s == "ColumnSortDescend") {
 			r = matrix_column_sort_descending(cx, goalscar, module);
 			return 1;
+		} else if (s == "copy") {
+			r = matrix_copy(cx, goalscar, module);
+			return 1;
 		}
 	}
 
@@ -673,7 +675,7 @@ int matrix_zero(Context* cx, Node* goalscar, List* module)
 	}
 
 	if (ncolumn->kind() != ATOM) {
-		syserr("usage: ::matrix <zero ROW COLUMN>\n");
+		syserr("usage: ::matrix <zero VAR ROW COLUMN>\n");
 		return 0;
 	}
 
@@ -4228,3 +4230,49 @@ int matrix_issingular(Context* cx, Node* goalscar, List* module)
 	return -1;
 }
 
+int matrix_copy(Context* cx, Node* goalscar, List* module)
+{
+	if (ListLength(goalscar->Cdr()) != 2) {
+		syserr("usage: ::matrix <copy VAR MATRIX>\n");
+		return 0;
+	}
+
+	Node* g    = goalscar->Cdr()->Val();
+
+	int rn;
+
+	Node* nvar = g->Car()->Val();
+	if ((rn = FuncArg(cx, nvar, goalscar, module)) <= 0) {
+		syserr("set: failed in the evaluation of the argument. \n");
+		return 0;
+	}
+
+	if (nvar->kind() != UNDEF) {
+		syserr("usage: ::matrix <copy VAR MATRIX>\n");
+		return 0;
+	}
+
+	g = g->Cdr();
+	Node* nmat = g->Car()->Val();
+	if ((rn = FuncArg(cx, nmat, goalscar, module)) <= 0) {
+		syserr("set: failed in the evaluation of the argument. \n");
+		return 0;
+	}
+
+	if (nmat->kind() != LIST) {
+		syserr("usage: ::matrix <copy VAR MATRIX>\n");
+		return 0;
+	}
+
+	Node* nmat2 = Dup(nmat);
+
+	Node* env = Nil->Cons(Nil);
+
+	SetEnv(env, nvar);
+	((Undef*)(nvar->Val()))->Set(nmat2);
+
+	PushStack(cx, Nil, Nil, env);
+	return 1;
+}
+
+
