@@ -1,5 +1,5 @@
 /*
- * Regular Expression program copyright (C) 2009 - 2010 H.Niwa
+ * Regular Expression program copyright (C) 2009 - 2011 H.Niwa
  */
 
 /*
@@ -23,40 +23,19 @@
 
 #include <stdio.h>
 
-#ifndef __MINGW32__
+#if HAVE_REGEX_H
 #include <regex.h>
-#endif /* __MINGW32__ */
+#endif /* HAVE_REGEX_H */
 
 #include <string>
 #include <complex>
 
 #include "syserr.h"
 
-#ifdef __MINGW32__
-int Regex(std::string ptn, std::string str, 
-		std::string& forestr, std::string& matchstr, 
-			std::string& reststr)
-{
-	syserr("disable regex\n");
-	return 0;
-}
+#include "regexheader.h"
 
-int Sub(std::string ptn, std::string str, 
-		std::string replacestr, std::string& outputstr)
-{
-	syserr("disable sub\n");
-	return 0;
-}
-
-int GSub(std::string ptn, std::string str, 
-		std::string replacestr, std::string& outputstr)
-{
-	syserr("disable gsub\n");
-	return 0;
-}
-
-#else 
 
+#if HAVE_REGEX_H
 int Regex(std::string ptn, std::string str, 
 		std::string& forestr, std::string& matchstr, 
 			std::string& reststr)
@@ -68,8 +47,12 @@ int Regex(std::string ptn, std::string str,
 	matchstr = "";
 
 	if ((r = regcomp(&reg, ptn.c_str(), REG_EXTENDED)) != 0) {
-		syserr("internal error: regcomp %d \n", r);
-		return 0;
+/*
+		char errbuf[1024];
+		regerror(r, &reg, errbuf, 1024-1);
+		fprintf(stderr, "regcomp %d : %s\n", r, errbuf);
+*/
+		return -1;
 	}
 	
 	r =  regexec(&reg, str.c_str(), 1, match, 0);
@@ -168,5 +151,36 @@ int GSub(std::string ptn, std::string str,
 	}
 }
 
-#endif /* __MINGW32__ */
+int GrepStr(std::string &ptn, std::string &str)
+{
+	std::string forestr="",  matchstr="", reststr="";
+	int r = Regex(ptn, str, forestr, matchstr, reststr);
 
+	return r;
+}
+
+int Grep_iStr(std::string ptn, std::string str)
+{
+	extern void str_tolower(std::string &str);
+
+	str_tolower(ptn);
+	str_tolower(str);
+	
+	std::string forestr="",  matchstr="", reststr="";
+	int r = Regex(ptn, str, forestr, matchstr, reststr);
+
+	return r;
+}
+
+int Grep_vStr(std::string &ptn, std::string &str)
+{
+	std::string forestr="",  matchstr="", reststr="";
+	int r = Regex(ptn, str, forestr, matchstr, reststr);
+	if (r == 1) {
+		return -1;
+	} else {
+		return 1;
+	}
+}
+
+#endif /* HAVE_REGEX_H */
