@@ -26,10 +26,10 @@
 // program start time
 struct ProgTime {
 	long long	start_time;
-	clock_t		start_utime;
-	clock_t		start_stime;
-	clock_t		start_cutime;
-	clock_t		start_cstime;
+	long		start_utime;
+	long		start_stime;
+	long		start_cutime;
+	long		start_cstime;
 };
 
 extern struct ProgTime progtime;
